@@ -1,14 +1,14 @@
-# ABSTRACT: Self-Validating Object System and Data Validation Framework
+# ABSTRACT: Simple Object System, Data Validation and Modeling Framework
 
 package Validation::Class;
 {
-  $Validation::Class::VERSION = '7.10_01';
+  $Validation::Class::VERSION = '7.01';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.10_01'; # VERSION
+our $VERSION = '7.01'; # VERSION
 
 use Module::Find;
 use Carp 'confess';
@@ -271,10 +271,6 @@ sub field {
     
     return undef unless ($name && $data);
     
-    confess "Error creating field $name, name is using unconventional naming"
-        unless $name =~ /^[a-zA-Z_](([\w\.]+)?\w)$/
-        xor    $name =~ /^[a-zA-Z_](([\w\.]+)?\w)\:\d+$/;
-    
     return configure_class_proto sub {
         
         my ($proto) = @_;
@@ -283,7 +279,7 @@ sub field {
         
         confess "Error creating accessor $name on $proto->{package}, ".
             "attribute collision" if exists $proto->{config}->{FIELDS}->{$name};
-        
+            
         confess "Error creating accessor $name on $proto->{package}, ".
             "method collision" if $proto->{package}->can($name);
         
@@ -293,32 +289,34 @@ sub field {
         
         no strict 'refs';
         
-        my $accessor = $name;
-        
-        $accessor =~ s/[^a-zA-Z0-9_]/_/g;
-        
-        my $accessor_routine = sub {
+        *{"$proto->{package}\::$name"} = sub {
             
             my ($self, $data) = @_;
             
-            my $proto  = $self->proto;
-            my $fields = $proto->fields;
+            # this method-of-operation can be computationally expensive due to
+            # the fact that each call serializes/de-serializes the params hash 
+            # ... research a better approach
+            
+            my $proto      = $self->proto;
+            my $fields     = $proto->fields;
+            my $parameters = $proto->get_params_hash;
+            
             my $result = undef;
             
-            if (defined $data) {
+            if (defined $data && not defined $fields->{$name}->{readonly}) {
                 
-                $proto->set_params($name => $data);
+                $parameters->{$name} = $data;
                 
             }
             
-            $result = $proto->get_value($name);
+            $result = $proto->field_default_value($name, $parameters);
+                
+            $proto->set_params_hash($parameters);
             
             return $result;
             
         };
         
-        *{"$proto->{package}\::$accessor"} = $accessor_routine;
-        
     };
     
 }
@@ -652,19 +650,10 @@ sub new {
     
     my %ARGS = @_ ? @_ > 1 ? @_ : "HASH" eq ref $_[0] ? %{$_[0]} : () : ();
     
-    # bless special collections
+    # process collection assignments
     
-    $proto->{errors} = Validation::Class::Errors->new;
-    $proto->{params} = Validation::Class::Params->new;
-    $proto->{fields} = Validation::Class::Fields->new($proto->{fields}); #!!!
-    
-    # process overridable attributes
-    
-    my $fields = delete $ARGS{fields} if defined $ARGS{fields};
-    my $params = delete $ARGS{params} if defined $ARGS{params};
-    
-    $proto->set_fields($fields) if $fields;
-    $proto->set_params($params) if $params;
+    $proto->{fields} = delete $ARGS{fields} if defined $ARGS{fields};
+    $proto->{params} = delete $ARGS{params} if defined $ARGS{params};
     
     # process attribute assignments
     
@@ -674,6 +663,12 @@ sub new {
         
     }
     
+    # bless specific collections
+    
+    $proto->{fields} = Validation::Class::Fields->new(%{$proto->{fields}});
+    
+    $proto->{params} = Validation::Class::Params->new(%{$proto->{params}});
+    
     # process plugins
     
     foreach my $plugin (keys %{$config->{PLUGINS}}) {
@@ -739,11 +734,11 @@ __END__
 
 =head1 NAME
 
-Validation::Class - Self-Validating Object System and Data Validation Framework
+Validation::Class - Simple Object System, Data Validation and Modeling Framework
 
 =head1 VERSION
 
-version 7.10_01
+version 7.01
 
 =head1 SYNOPSIS
 
@@ -957,7 +952,7 @@ you can create a no-op by simply returning true, e.g.:
 =head2 field
 
 The field keyword (or fld) creates an attribute with validation rules for reuse
-in code. The field name should correspond with the parameter name expected to
+in code. The field keyword may also correspond with the parameter name expected to
 be passed to your validation class.
 
     package MyApp::User;
@@ -971,42 +966,11 @@ be passed to your validation class.
         ...
     };
 
-The field keyword takes two arguments, the field name and a hashref of
-key/values pairs known as directives.
+The field keyword takes two arguments, the field name and a hashref of key/values
+pairs known as directives.
 
-The field keyword also creates accessors which provide easy access to the
-field's corresponding parameter value(s). Accessors will be created using the
-field's name as a label having any special characters replaced with an
-underscore.
-
-    field 'login' => {
-        required   => 1,
-        min_length => 1,
-        max_length => 255,
-        ...
-    };
-    
-    field 'preference.send_reminders' => {
-        required   => 1,
-        max_length => 1,
-        ...
-    };
-    
-    field 'preference.send_reminders.text:0' => {
-        ...
-    };
-    
-    my $value = $self->login;
-    
-    $self->login($new_value); # arrayrefs and hashrefs will be flattened
-    
-    $self->preference_send_reminders;
-    
-    $self->preference_send_reminders_text_0;
-
-Protip: Field directives are used to validate scalar and array data. Don't use
-fields to store and validate blessed objects. Please see the *has* keyword
-instead.
+Protip: Fields are used to validate constant and array data, not hashrefs and
+objects. Don't try to use fields like attributes (use the has keyword instead).
 
 =head2 filter
 
