@@ -2,13 +2,13 @@
 
 package Validation::Class::Collection;
 {
-  $Validation::Class::Collection::VERSION = '7.10_01';
+  $Validation::Class::Collection::VERSION = '7.01';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.10_01'; # VERSION
+our $VERSION = '7.01'; # VERSION
 
 use Carp 'confess';
 
@@ -72,11 +72,9 @@ sub each {
     
     my ($self, $transformer) = @_;
     
-    $transformer ||= sub {@_};
+    $transformer ||= sub {@_} ;
     
-    my %hash = %{$self};
-    
-    while (my @kv = each(%hash)) {
+    while (my @kv = each(%{$self})) {
         
         $transformer->(@kv);
         
@@ -103,15 +101,6 @@ sub find {
 }
 
 
-sub has {
-    
-    my ($self, $name) = @_;
-    
-    return defined $self->{$name} ? 1 : 0;
-    
-}
-
-
 sub hash {
     
     return {%{$_[0]}};
@@ -133,15 +122,6 @@ sub list {
 }
 
 
-sub remove {
-    
-    my ($self, $name) = @_;
-    
-    return delete $self->{$name} if $name;
-    
-}
-
-
 sub values {
     
     goto &list;
@@ -158,7 +138,7 @@ Validation::Class::Collection - Generic Container Class for Various Collections
 
 =head1 VERSION
 
-version 7.10_01
+version 7.01
 
 =head1 SYNOPSIS
 
@@ -208,12 +188,6 @@ This class is primarily used as a base class for collection management classes.
 
     my $matches = $self->find(qr/update_/); # hashref
 
-=head2 has
-
-    if ($self->has($name)) {
-        ...
-    }
-
 =head2 hash
 
     my $hash = $self->hash; 
@@ -226,10 +200,6 @@ This class is primarily used as a base class for collection management classes.
 
     my @objects = $self->list;
 
-=head2 remove
-
-    $object = $self->remove($name);
-
 =head2 values
 
     my @objects = $self->values;
