@@ -2,13 +2,13 @@
 
 package Validation::Class::Fields;
 {
-  $Validation::Class::Fields::VERSION = '7.10_01';
+  $Validation::Class::Fields::VERSION = '7.01';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.10_01'; # VERSION
+our $VERSION = '7.01'; # VERSION
 
 use Carp 'confess';
 
@@ -39,11 +39,7 @@ sub add {
     
 }
 
-sub clear {
-    
-    #noop - fields can't be deleted this way
-    
-}
+sub clear {} #noop
 
 1;
 __END__
@@ -55,7 +51,7 @@ Validation::Class::Fields - Container Class for Validation::Class::Field Objects
 
 =head1 VERSION
 
-version 7.10_01
+version 7.01
 
 =head1 SYNOPSIS
 
